@@ -1,13 +1,13 @@
-# Copyrights 1998,2005-2015 by [Mark Overmeer].
+# Copyrights 1998,2005-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package CPAN::Site::Index;
 use vars '$VERSION';
-$VERSION = '1.12';
+$VERSION = '1.13';
 
 use base 'Exporter';
 
@@ -80,14 +80,15 @@ sub cpan_index($@)
 
     my $global      = catdir $mycpan, 'global';
     my $mods        = catdir $mycpan, 'modules';
-    mkdirhier $global, $mods;
+    my $authors     = catdir $mycpan, 'authors';
+    mkdirhier $global, $mods, $authors;
 
     my $globdetails = update_global_cpan $mycpan, $globalcpan;
 
     # Create mailrc and modlist
 
     safe_copy catfile($global, '01mailrc.txt.gz')
-            , catfile($mycpan, authors => '01mailrc.txt.gz');
+            , catfile($authors, '01mailrc.txt.gz');
 
     safe_copy catfile($global, '03modlist.data.gz')
             , catfile($mods, '03modlist.data.gz');
